CreatedUserResult class

Result of UserProvider.createUser: the saved user plus the one-time plaintext password (never stored after this call).

Constructors

CreatedUserResult({required UserPublic user, required String temporaryPassword})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporaryPassword String
final
user → UserPublic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited