PersistedTokenProvider<A extends AuthServiceAbstract> class

Provider for managing persisted tokens using AuthService

Constructors

PersistedTokenProvider(A authService)

Properties

authService → A
final
hashCode int
The hash code for this object.
no setterinherited
isEmptyOrExpired bool
no setter
refreshToken String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAccessToken() Future<String>
Clear access token
clearRefreshToken() Future<String>
Clear refresh token
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readAccessToken() Future<String>
Read access token from storage
readAndSetRefreshToken() Future<String>
Read and set refresh token from storage
setAndUpsertAccessToken(String val) Future<String>
Set and persist access token
setAndUpsertRefreshToken(String val) Future<String>
Set and persist refresh token
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited