UserPublicExtension extension
Extension methods for the UserPublic protobuf class to provide convenient access and formatting of user data
- on
-
- UserPublic
Properties
-
detailsMap
→ Map<
String, String> -
Available on UserPublic, provided by the UserPublicExtension extension
Gets a map of user details for displayno setter - formattedCreatedAt → String
-
Available on UserPublic, provided by the UserPublicExtension extension
Gets a formatted creation date stringno setter - formattedLastSignIn → String
-
Available on UserPublic, provided by the UserPublicExtension extension
Gets a formatted last update date stringno setter - fullName → String
-
Available on UserPublic, provided by the UserPublicExtension extension
Gets the full name of the userno setter
Methods
-
copyWith(
{String? userId, String? mail, String? firstname, String? lastname, Phone? phone, Timestamp? lastSignIn, UserPermissions? permissions, Map< String, String> ? othersAttributes}) → UserPublic -
Available on UserPublic, provided by the UserPublicExtension extension
Creates a copy of the user with updated fields