LicenseSeatClient class
Low-level licence attribution validity (mirrors server LicenseSeatEntitlement).
Licences are lifetime purchases, not subscriptions; License.validUntil and
LicenseSeat.validUntil are for clean shutdown (abuse, etc.), not plan expiry.
See docs/commercial-model.md. For portal features, prefer SeatCapability.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
isLicenseCurrentlyValid(
License license, {DateTime? now}) → bool -
isSeatTimeWindowActive(
LicenseSeat seat, DateTime at) → bool -
timestampToUtc(
Timestamp t) → DateTime -
userHasActiveLicensedSeat(
String userId, Iterable< License> licenses, {DateTime? now}) → bool